@@ -16,10 +16,15 @@
 #include <xdp/xdp_sample_common.bpf.h>
 #include <linux/if_ether.h>
 
+#ifndef HAVE_LIBBPF_BPF_PROGRAM__TYPE
+static long (*bpf_xdp_load_bytes)(struct xdp_md *xdp_md, __u32 offset, void *buf, __u32 len) = (void *) 189;
+static long (*bpf_xdp_store_bytes)(struct xdp_md *xdp_md, __u32 offset, void *buf, __u32 len) = (void *) 190;
+#endif
+
 const volatile int ifindex_out;
 
 SEC("xdp")
-int xdp_redirect_basic_prog(struct xdp_md *ctx)
+int xdp_redirect_prog(struct xdp_md *ctx)
 {
 	void *data_end = (void *)(long)ctx->data_end;
 	void *data = (void *)(long)ctx->data;
@@ -41,4 +46,30 @@ int xdp_redirect_basic_prog(struct xdp_md *ctx)
 	return bpf_redirect(ifindex_out, 0);
 }
 
+SEC("xdp")
+int xdp_redirect_load_bytes_prog(struct xdp_md *ctx)
+{
+	__u32 key = bpf_get_smp_processor_id();
+	int err, offset = 0;
+	struct datarec *rec;
+	struct ethhdr eth;
+
+	err = bpf_xdp_load_bytes(ctx, offset, &eth, sizeof(eth));
+	if (err)
+		return err;
+
+	rec = bpf_map_lookup_elem(&rx_cnt, &key);
+	if (!rec)
+		return XDP_PASS;
+	NO_TEAR_INC(rec->processed);
+
+	swap_src_dst_mac(&eth);
+
+	err = bpf_xdp_store_bytes(ctx, offset, &eth, sizeof(eth));
+	if (err)
+		return err;
+
+	return bpf_redirect(ifindex_out, 0);
+}
+
 char _license[] SEC("license") = "GPL";
