@@ -59,10 +59,9 @@ check_packet()
     local command="$2"
     local expect="$3"
     echo "Checking command '$command' filter '$filter'"
-    PID=$(start_background tcpdump --immediate-mode -epni $NS "$filter")
+    PID=$(start_tcpdump tcpdump --immediate-mode -epni $NS "$filter")
     echo "Started listener as $PID"
     ns_exec bash -c "$command"
-    sleep 1
     output=$(stop_background $PID)
     echo "$output"
 
@@ -87,7 +86,7 @@ check_port()
     local port=$2
     local expect=$3
     echo "$type port $port $expect"
-    [[ "$type" == "tcp" ]] && command="echo test | socat - TCP6:[$OUTSIDE_IP6]:$port,connect-timeout=1"
+    [[ "$type" == "tcp" ]] && command="echo test | socat - TCP6:[$OUTSIDE_IP6]:$port,connect-timeout=0.1"
     [[ "$type" == "udp" ]] && command="echo test | socat - UDP6:[$OUTSIDE_IP6]:$port"
 
     check_packet "$type dst port $port" "$command" $expect
@@ -132,7 +131,12 @@ test_ports_deny()
 
 check_ping6()
 {
-    check_packet "dst $OUTSIDE_IP6" "$PING6 -c 1 $OUTSIDE_IP6" $1
+    check_packet "dst $OUTSIDE_IP6" "$PING6 -W 0.1 -c 1 $OUTSIDE_IP6" $1
+}
+
+check_ndisc6()
+{
+    check_packet "icmp6" "ndisc6 -r 1 $OUTSIDE_IP6 -s $INSIDE_IP6 veth0" $1
 }
 
 test_ipv6_allow()
@@ -141,8 +145,10 @@ test_ipv6_allow()
     check_run $XDP_FILTER load -f ipv6 $NS -v
     check_run $XDP_FILTER ip $OUTSIDE_IP6
     check_ping6 NOTOK
+    check_ndisc6 NOTOK
     check_run $XDP_FILTER ip -r $OUTSIDE_IP6
     check_ping6 OK
+    check_ndisc6 OK
     check_run $XDP_FILTER ip -m src $INSIDE_IP6
     check_ping6 NOTOK
     check_run $XDP_FILTER ip -m src -r $INSIDE_IP6
@@ -156,8 +162,10 @@ test_ipv6_deny()
     check_run $XDP_FILTER load -p deny -f ipv6 $NS -v
     check_run $XDP_FILTER ip $OUTSIDE_IP6
     check_ping6 OK
+    check_ndisc6 OK
     check_run $XDP_FILTER ip -r $OUTSIDE_IP6
     check_ping6 NOTOK
+    check_ndisc6 NOTOK
     check_run $XDP_FILTER ip -m src $INSIDE_IP6
     check_ping6 OK
     check_run $XDP_FILTER ip -m src -r $INSIDE_IP6
@@ -167,21 +175,37 @@ test_ipv6_deny()
 
 check_ping4()
 {
-    check_packet "dst $OUTSIDE_IP4" "ping -c 1 $OUTSIDE_IP4" $1
+    check_packet "dst $OUTSIDE_IP4" "ping -W 0.1 -c 1 $OUTSIDE_IP4" $1
+}
+
+check_arp()
+{
+    check_packet "arp" "arping -c 1 -I veth0 $OUTSIDE_IP4" $1
+}
+
+check_arp_src()
+{
+    check_packet "arp" "arping -A -c 1 -I veth0 $INSIDE_IP4" $1
 }
 
 test_ipv4_allow()
 {
     check_ping4 OK
     check_run $XDP_FILTER load -f ipv4 $NS -v
+    check_arp OK
+    check_arp_src OK
     check_run $XDP_FILTER ip $OUTSIDE_IP4
     check_ping4 NOTOK
+    check_arp NOTOK
     check_run $XDP_FILTER ip -r $OUTSIDE_IP4
     check_ping4 OK
+    check_arp OK
     check_run $XDP_FILTER ip -m src $INSIDE_IP4
     check_ping4 NOTOK
+    check_arp_src NOTOK
     check_run $XDP_FILTER ip -m src -r $INSIDE_IP4
     check_ping4 OK
+    check_arp_src OK
     check_run $XDP_FILTER unload $NS -v
 }
 
@@ -191,12 +215,16 @@ test_ipv4_deny()
     check_run $XDP_FILTER load -p deny -f ipv4 $NS -v
     check_run $XDP_FILTER ip $OUTSIDE_IP4
     check_ping4 OK
+    check_arp OK
     check_run $XDP_FILTER ip -r $OUTSIDE_IP4
     check_ping4 NOTOK
+    check_arp NOTOK
     check_run $XDP_FILTER ip -m src $INSIDE_IP4
     check_ping4 OK
+    check_arp_src OK
     check_run $XDP_FILTER ip -m src -r $INSIDE_IP4
     check_ping4 NOTOK
+    check_arp_src NOTOK
     check_run $XDP_FILTER unload $NS -v
 }
 
